@@ -3,7 +3,7 @@ from gateoverflow.state import state as s
 from gateoverflow import constants
 from gateoverflow.logger import d
 from gateoverflow import queries as q
-from gateoverflow.helpers import readable_date, open_link, uncrawled_metadata_count, crawl_metadata, prettify_table, print_logo, ask, latest_version_check
+from gateoverflow.helpers import readable_date, open_link, uncrawled_metadata_count, crawl_metadata, prettify_table, print_title, ask, latest_version_check
 modes = constants.modes
 
 
@@ -69,7 +69,8 @@ def print_help():
 def clear_screen():
     cmd = 'clear' if os.name == 'posix' else 'cls'
     os.system(cmd)
-    print_logo()
+    if s['show_title']:
+        print_title()
 
 
 def debug_toggle():
